/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import palm.conduit.*;
import java.io.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;


public class ConduitProgress implements WindowListener, ActionListener {

    private ConduitConfigure config;

    /** The Configuration dialog
    */
    private Dialog progressDialog;

    private String status;

    private int numServers;
    private int currentServer;
    private String currentServerName;

    private String currentNewsgroupName;

    private int numArticles;
    private int currentArticle;

    private Label lServerProgress;
    private Label lNewsgroupProgress;
    private Label lArticleProgress;
    private Label lStatus;

    /** Constructor. Takes the name of the conduit
    *	and the path to the configuration file as arguments
    */
    public ConduitProgress(ConduitConfigure config) {
        numServers = 0;
        currentServer = 0;
        currentServerName = "<unknown>                      ";
        currentNewsgroupName = "<unknown>                      ";
        numArticles = 0;
        currentArticle = 0;
        status = "";
    }

    public void setStatus(String status) { this.status = status; lStatus.setText(status); }
    public void setNumServers(int num) { numServers = num; lServerProgress.setText(makeServerProgress());}
    public void setCurrentServer(int current) { currentServer = current; lServerProgress.setText(makeServerProgress());}
    public void setCurrentServerName(String current) { currentServerName = current; lServerProgress.setText(makeServerProgress());}

    public void setCurrentNewsgroupName(String current) { currentNewsgroupName = current;  lNewsgroupProgress.setText(makeNewsgroupProgress()); }

    public void setCurrentArticle(int current) { currentArticle = current;  lArticleProgress.setText(makeArticleProgress());}
    public void setNumArticles(int num) { numArticles = num; lArticleProgress.setText(makeArticleProgress()); }

    private String makeServerProgress() {
        return "Server " + currentServerName + " ("+currentServer+" of "+numServers+")";
    }

    private String makeNewsgroupProgress() {
        return "Newsgroup " + currentNewsgroupName;
    }

    private String makeArticleProgress() {
        return "Article "+currentArticle+" of "+numArticles;
    }

    /** Creates the configuration dialog box.
    */
    public int createDialog() {

        Dimension dim;

        Frame f = new Frame();

	// Create a dialog
	progressDialog = new Dialog(f, "Progress");
	progressDialog.setModal(false);
	progressDialog.setBackground(SystemColor.control);

	progressDialog.setLayout(new GridBagLayout());

	// Create a constraints object, and specify some default values
	GridBagConstraints c = new GridBagConstraints();
	c.fill = GridBagConstraints.BOTH;   // components grow in both dimensions
	c.insets = new Insets(5,5,5,5); // 5-pixel margins on all sides

	// Create the components
        lStatus = new Label(status);
        lServerProgress = new Label(makeServerProgress());
        lNewsgroupProgress = new Label(makeNewsgroupProgress());
        lArticleProgress = new Label(makeArticleProgress());

	int line=-1;

	c.gridx = 0; c.gridy = ++line; c.gridwidth = 2; c.gridheight = 1;
	c.weightx = 1.0; c.weighty = 0.0;
	progressDialog.add(lStatus, c);

	c.gridx = 0; c.gridy = ++line; c.gridwidth = 2; c.gridheight = 1;
	c.weightx = 1.0; c.weighty = 0.0;
	progressDialog.add(lServerProgress, c);

	c.gridx = 0; c.gridy = ++line; c.gridwidth = 2; c.gridheight = 1;
	c.weightx = 1.0; c.weighty = 0.0;
	progressDialog.add(lNewsgroupProgress, c);

	c.gridx = 0; c.gridy = ++line; c.gridwidth = 2; c.gridheight = 1;
	c.weightx = 1.0; c.weighty = 0.0;
	progressDialog.add(lArticleProgress, c);

        // Size the dialog
	dim = progressDialog.getToolkit().getScreenSize();
	progressDialog.setLocation(dim.width/2,dim.height/2);
//        progressDialog.setSize(500, 600);
//        progressDialog.validate();
        progressDialog.pack();
	progressDialog.addWindowListener(this);

	progressDialog.show();

	return 0;
    }


    public void actionPerformed(ActionEvent e) {

	Button b = (Button)e.getSource();

	if(b.getLabel().equals("Cancel")) {
	    progressDialog.dispose();
	    return;
	} else if(b.getLabel().equals("Help")) {
	    // if help, pop up text window with help info

	} else if(b.getLabel().equals("OK")) {
	    progressDialog.dispose();
	    return;
	}
    }

    public void windowOpened(WindowEvent e) {}
    public void windowClosing(WindowEvent e) {
        // Dialog dismissed, don't save changes
	progressDialog.dispose();
    }
    public void windowClosed(WindowEvent e) {}
    public void windowIconified(WindowEvent e) {}
    public void windowDeiconified(WindowEvent e) {}
    public void windowActivated(WindowEvent e) {}
    public void windowDeactivated(WindowEvent e) {}

    public void close() { progressDialog.dispose(); } 

}

