/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import java.io.*;
import java.util.*;
import palm.conduit.*;


public class HistoryRecord extends PalmRecord implements Comparable {
    public Date date;
    public String msgid;

    public HistoryRecord() {
    }

    public HistoryRecord(Date date, String msgid) {
        this.date = date; this.msgid = msgid;
    }

    public int compareTo(Object o) {
        if (o == null || o.getClass() != this.getClass())
            throw new ClassCastException();
        HistoryRecord other = (HistoryRecord) o;
	return msgid.compareTo(other.msgid);
    }

    public void writeData(DataOutputStream out) throws java.io.IOException {
        out.writeInt(dateToPalmSec(date)); 
        if (msgid != null) {
            out.write(msgid.getBytes());
        }
        out.writeByte(0);
    }

    public void readData(DataInputStream in) throws java.io.IOException {
        date = palmSecToDate(in.readInt());
        msgid = readCString(in);
    }

    public String toString() {
        return "MsgID: " + msgid;
    }

    public String toFormattedString() {
        return ("HistoryRecord: {\n" + 
		"  MsgID: " + msgid + "\r\n"+
		"  date: "+date.toLocaleString() + "\r\n"+
  	        "}\r\n" + 
	        super.toFormattedString());

    }
}
