/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import palm.conduit.*;
import java.util.*;
import java.io.*;
import java.lang.*;

public class NewsRC {
    protected File file = null;
    protected boolean dirty = false;
    protected Vector groups = null;

    public NewsRC() {
        groups = new Vector();
    }

    public NewsRC(File file) throws FileNotFoundException, IOException {
        this.file = file;
        groups = new Vector();
        read(); 
    }

    public NewsRC(String filename) throws FileNotFoundException, IOException {
        this.file = new File(filename);
        groups = new Vector();
        read(); 
    }

    public void save() throws IOException { if (dirty) write(); }

    void markDirty() { dirty = true; }

    protected void read() {
        String line=null;
        try {
            BufferedReader reader = new BufferedReader(new FileReader(file));
            while (reader.ready()) {
                line = reader.readLine();
                if ( line != null && !line.equals("") ) {
                    NewsRCGroup group = new NewsRCGroup(this, line);
                    groups.addElement(group);
                }
            }
            reader.close();
        } catch (IOException e) {
            // do nothing, that's OK.            
        }
    }

    protected void write() throws IOException {
        String line=null;
        BufferedWriter writer = new BufferedWriter(new FileWriter(file));
        Util.DEBUG(3, "Writing newsrc "+file.getName());

        for (Enumeration e = groups.elements(); e.hasMoreElements(); ) {
            NewsRCGroup group = (NewsRCGroup) e.nextElement();
            writer.write(group.toString() + "\n");
        }
        writer.close();
    }

    public NewsRCGroup getGroup(String newsgroup) throws IOException {
        boolean finished = false;
        NewsRCGroup group = null;

        for (Enumeration e = groups.elements(); e.hasMoreElements() && !finished; ) {
            group = (NewsRCGroup) e.nextElement();
            finished = group.group.equals(newsgroup);
        }

        if (!finished)
        {
            group = new NewsRCGroup(this, newsgroup, true);
            groups.addElement(group);
        } 
        return group;
    }

}

