/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import palm.conduit.*;
import java.util.*;
import java.io.*;
import java.lang.*;

public class Newsgroup extends PalmDatabase {
    PalmDatabase articles;
    public Newsgroup(String name, int creator, int type, Class recordType, int flags, PalmDatabase articles) throws IOException { 
        super(name, creator, type, recordType, flags);
        this.articles = articles;
    }

    public void thread(ConduitProgress progress) throws IOException {
        Util.DEBUG(3, "Threading " + name + " ("+getRecordCount()+" records), starting at "+new Date(System.currentTimeMillis()).toLocaleString());
        Util.DEBUG(3, "    First read records to cache "+new Date(System.currentTimeMillis()).toLocaleString());
        if (Util.debugLevel>=3) progress.setStatus("Threading, reading...");        
        for (int i=0; i<getRecordCount(); i++) getRecordByIndex(i); // make sure all records are in the cache

        Util.DEBUG(3, "    Finished reading records, now threading "+new Date(System.currentTimeMillis()).toLocaleString());
	Threader threader = new Threader();
        threader.thread(this, articles, progress);
        Util.DEBUG(3, "    Finished threading, now rewriting "+new Date(System.currentTimeMillis()).toLocaleString());

        if (Util.debugLevel>=3 && getRecordCount()<20) {
            Log.out(threader.toString());
        }

        // Remove all records from the Palm and the cache
        clearAllRecords();

        // And write them back in the proper order
        if (Util.debugLevel>=3) progress.setStatus("Threading, writing...");        
	int i=0;
        for (Enumeration e=threader.order(); e.hasMoreElements(); i++) {
            ArticleRecord article = (ArticleRecord) e.nextElement();
            NewsgroupRecord record = new NewsgroupRecord(article.getId());
            addRecord(record);
        }
        if (Util.debugLevel>=3) progress.setStatus("Threading, cleaning up...");        
        threader.cleanup();	
        if (Util.debugLevel>=3) progress.setStatus("Threading, finished...");        

        Util.DEBUG(3, "Finished threading " + name + " at "+new Date().toLocaleString());
    }

}


