/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import java.io.*;
import java.util.*;
import palm.conduit.*;


public abstract class PalmRecord extends AbstractRecord {
    int indexOnPalm;

    boolean dirty=false;
    boolean added=false;
    boolean deleted=false;

    public void markDirty() { dirty = true; }
    public void markNew() { added = true; }
    public void markDeleted() { deleted = true; }

    public boolean isDirty() { return dirty; }
    public boolean isNew() { return added; }
    public boolean isDeleted() { return deleted; }

    static int dateToPalmSec(Date date) throws IOException {
        long PALM_START_TIME = (new GregorianCalendar(1904, Calendar.JANUARY, 1)).getTime().getTime();

        long javamSec = date.getTime();
        long palmSec = (javamSec - PALM_START_TIME) / 1000;
        if (palmSec >= (((long) 1) << 31)) { palmSec -= (((long) 1) << 32); }
        return (int) palmSec;
    }

    static Date palmSecToDate(int palmSec) throws IOException {
        long PALM_START_TIME = (new GregorianCalendar(1904, Calendar.JANUARY, 1)).getTime().getTime();

        long l = (long) palmSec;
        if (l<0) { l += (((long) 1) << 32); } // Unsigned in Palm database
        long javamSec = (l * 1000) +  PALM_START_TIME; // Palm calender start at 1904/1/1, in Java january==0
        Date date = new Date(javamSec);
        return date;
    }

    void writeSecDate(DataOutputStream out, Date date) throws IOException {
        out.writeInt(dateToPalmSec(date));
    }

    Date readSecDate(DataInputStream in) throws IOException {
        int palmSec = in.readInt();
        return palmSecToDate(palmSec);
    }

}
