/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import java.util.*;
import java.io.*;
import java.lang.*;

public class Range implements Comparable {
    long from = 0;
    long to = 0;

    public Range() {}

    public Range(long from, long to) {
        this.from = from; this.to = to; 
    }

    public Range(Range r) {
        this.from = r.from; this.to = r.to; 
    }

    public void set(long from, long to) {
        this.from = from; this.to = to; 
    }

    public int compare(Object o1, Object o2) {
        if ( (this.getClass() != o2.getClass()) || (this.getClass() != o2.getClass())) {
            throw new ClassCastException();
        }
        return (((Range) o1).from < ((Range) o2).from) ? -1 : ((((Range) o1).from == ((Range) o2).from) ? 0 : 1);
    }

    public int compareTo(Object o) {
        return compare(this, o);
    }

    public String toString() {
        return (from==to) ? Long.toString(from) : Long.toString(from) + "-" + Long.toString(to);
    }

    public void setFrom(long from) { this.from = from; }
    public void setTo(long to) { this.to = to; }

    public long getFrom() { return this.from; }
    public long getTo() { return this.to; }
}

