/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import java.io.*;
import java.util.*;
import palm.conduit.*;

public class ServerRecord extends PalmRecord {
    public int port;
    public int timeoutsecs;
    public boolean poll;		// should Yanoff poll this server right now?
    public boolean use_auth;
    public String name;				// to identify server config
    public String address;
    public String auth_user;
    public String auth_pass;
    public String hostname;          // our hostname
    public String username;          // sender name. from = username@hostname
    public String realname;
    public String zone;
    public String sig;
    // 10 dummy bytes (NULL) in database at this place, says header file in Yanoff
    // source, but not in c file
    public int serverType;

    static final int MAIL_SERVER = 0;
    static final int NEWS_SERVER = 1;
 
    public boolean getPoll() {
        return this.poll;
    }

    public void writeData(DataOutputStream out) throws java.io.IOException {
        out.writeShort(port);
        out.writeShort(timeoutsecs);

        if (poll) out.writeByte(1); else out.writeByte(0);
        if (use_auth) out.writeByte(1); else out.writeByte(0);

        if (name != null) out.write(name.getBytes());
        out.writeByte(0);

        if (address != null) out.write(address.getBytes());
        out.writeByte(0);

        if (auth_user != null) out.write(auth_user.getBytes());
        out.writeByte(0);
    
        if (auth_pass != null) out.write(auth_pass.getBytes());
        out.writeByte(0);

        if (hostname != null) out.write(hostname.getBytes());
        out.writeByte(0);

        if (username != null) out.write(username.getBytes());
        out.writeByte(0);

        if (realname != null) out.write(realname.getBytes());
        out.writeByte(0);

        if (zone != null) out.write(zone.getBytes());
        out.writeByte(0);

        if (sig != null) out.write(sig.getBytes());
        out.writeByte(0);
    }

    public void readData(DataInputStream in) throws java.io.IOException {
        port = in.readShort();
        timeoutsecs = in.readShort();

        poll = !(in.readByte() != 1); 
        use_auth = !(in.readByte() != 1); 

        name = readCString(in);
        address = readCString(in);
        auth_user = readCString(in);
        auth_pass = readCString(in);
        hostname = readCString(in);        
        username = readCString(in);         
        realname = readCString(in);
        zone = readCString(in);
        sig = readCString(in);

        if (getIndex() == 0) serverType = MAIL_SERVER; else serverType = NEWS_SERVER;
    }

    /** Returns a string representation of the object */
    public String toString() {
        String s = "";
        switch (serverType) {
        case ServerRecord.MAIL_SERVER: 
            s = "Mail server: " + this.address; //  + " " + super.toString();
            break;
        case ServerRecord.NEWS_SERVER: 
            s = "News server: " + this.address; //  + " " + super.toString();
            break;
        }
        return s;
    }

    /** Returns a formatted string representation of the object */
    public String toFormattedString() {
        return ("Server record: {\r\n" +
                "  port: " + this.port + "\r\n" +
                "  timeoutsecs: " + this.timeoutsecs + "\r\n" +
                "  poll: " + this.poll + "\r\n" +
                "  use_auth: " + this.use_auth + "\r\n" +
                "  name: " + this.name + "\r\n" +
                "  address: " + this.address + "\r\n" +
                "  auth_user: " + this.auth_user + "\r\n" +
                "  auth_pass: " + this.auth_pass + "\r\n" +
                "  hostname: " + this.hostname + "\r\n" +
                "  username: " + this.username + "\r\n" +
                "  realname: " + this.realname + "\r\n" +
                "  zone: " + this.zone + "\r\n" +
                "  sig: " + this.sig + "\r\n" +
                "  type: " + this.serverType + "\r\n" +
                "}\r\n" +
                super.toFormattedString());
    }

}
