/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import palm.conduit.*;
import java.util.*;
import java.io.*;
import java.lang.*;

public class Sorter {
 
    private static String partToString(Vector vector, int start, int end) {
        String s = "";
        for (int i=start; i<=end; i++){
            Object o = vector.elementAt(i);
            s = s + i + ": " + o.toString() + "\n";
        }
        return s;
    }

    private static void swap(Vector vector, int from, int to) {
        Object temp = vector.elementAt(from);
        vector.setElementAt(vector.elementAt(to), from);
        vector.setElementAt(temp, to);
    }

    private static int partition(Vector vector, int start, int end) {
        int pivot = (start + end)/2;
        swap(vector, start, pivot);
        Comparable pivotValue = (Comparable) vector.elementAt(start);
	int up=start-1;
	int down=end+1;
        do {
            do {down--;} while (down>start && pivotValue.compareTo(vector.elementAt(down)) < 0);
            do {up++;} while (up<end && pivotValue.compareTo(vector.elementAt(up)) > 0);
	    if (up<down) {
                swap(vector, up,down);
            }
        } while (up<down); 
        return down;
    }

    private static void quicksort(Vector vector, int start, int end)
    {
      if (start < end) {   
            int boundary = partition(vector, start, end);
            quicksort(vector, start, boundary);
            quicksort(vector, boundary+1, end);
        }
    }

    public static void quicksort(Vector vector) {
        quicksort(vector, 0, vector.size()-1);
    }
}


