/**
 * Title:        Yanoff Conduit
 * Description:  A Java conduit for the Yanoff PalmOS newsreader.
 * Copyright:    Copyright (c) Jan-Pascal van Best
 * Email:	     janpascal@vanbest.org
 * @author       Jan-Pascal van Best
 **************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, version 2.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package org.vanbest.yanoff;

import java.util.*;
import java.io.*;
import java.lang.*;
import palm.conduit.*;

public class Test {

    public static void main(String[] args) {
        System.out.println("Starting test...");
        try { 
            // dateSorter();
            // groupTest();
            mailTest();
        } catch(Throwable t) {
            System.out.println("Oops");
            t.printStackTrace();
        }
        System.out.println("Finished test...");
        System.exit(0);
    }

    static void mailTest() throws Throwable {
        SMTPClient SMTP = new SMTPClient("tb0nt1.sepa.tudelft.nl");
        Header header = new Header();
        header.addHeaderLine("From", "J.P. van Best <janb@sepa.tudelft.nl>");
        header.addHeaderLine("To", "Jan-Pascal van Best <janb@sepa.tudelft.nl>, " +
                "\"'Jan-Pascal van Best'\" <jvbest@wi.leidenuniv.nl>," +
                "jpvanbest@europe.com (Jan-Pascal van Best)");
        header.addHeaderLine("Subject", "Test, please ignore");
        header.addHeaderLine("Date", "23 May 2000 11:17:27 GMT");
        header.addHeaderLine("X-Mailer", "Yanoff Experimental");

        SMTP.mailMessage(header, "Dit is een test\n-- \nEmpty .sig\n");
    }
    static void postTest() throws Throwable {
        NewsClient news = new NewsClient();
        news.connect("news.tudelft.nl");
        Header header = new Header();
        header.addHeaderLine("From", "janb@tbm.tudelft.nl");
        header.addHeaderLine("Newsgroups", "dut.test");
        header.addHeaderLine("Subject", "Test, please ignore");
        header.addHeaderLine("Date", "23 May 2000 11:17:27 GMT");
        header.addHeaderLine("X-Newsreader", "Yanoff Experimental");

        news.postArticle(header, "Dit is een test\n-- \nEmpty /sig\n");
    }

    static void groupTest() throws Throwable {
        NewsClient news = new NewsClient();
        news.connect("news.cis.dfn.de");
        news.login("best", "quootafi");
        NewsgroupInfo info = new NewsgroupInfo();
        news.selectGroup("nl.test", info);
        System.out.println(info.toString());
//        Header header = news.getHeader(info.last);
//        System.out.println(header);

        NewsArticle article = news.getArticle(info.last);
        System.out.println(article.toString());
        news.disconnect();
        System.out.println(article.header.valueOf("DAte"));
    }

    static void dateSorter() throws Throwable {
        Vector test = new Vector();
        test.addElement(new TestElement(new Date(0)));
        test.addElement(new TestElement(new Date(0)));
        test.addElement(new TestElement(new Date(0)));

/*        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement((Date) null)); 
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement((Date) null)); 
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement("8 May 2000"));
        test.addElement(new TestElement((Date) null)); 

        test.addElement(new TestElement(new Date((new Date()).getTime() - (long) (Math.random()*1000*60*60*24*40))));

        test.addElement(new TestElement((Date) null)); 
*/
        System.out.println(test.toString());
        Sorter.quicksort(test);
        System.out.println(test.toString());
    }

}

class TestElement implements Comparable {
    Date date;

    public TestElement(Date date) {
        this.date = date;
    }

    public TestElement(String date) {
        if (date == null || date.equals(""))
            this.date = new Date(0);
        else 
            try {
                this.date = new Date(date);
            } catch (IllegalArgumentException e) {
                System.out.println("Cannot parse date "+date+" : "+e.getMessage());
                this.date = new Date(0);
            }
    }

    public int compareTo(Object o) {
        if (o == null || o.getClass() != this.getClass())
            throw new ClassCastException();
        TestElement other = (TestElement) o;
        if (date == null && other.date == null) return 0;
        else if (date == null) return -1;
        else if (other.date == null) return 1;
        else if (date.equals(other.date)) return 0;
	else return (date.before(other.date) ? -1 : 1);
    }

    public String toString() {
        return (date == null ? null : date.toString());
    }
}
